@@ -35,9 +35,9 @@ imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
   const gchar *image_path, *title;
   guchar *online_file_name = NULL;
   guchar *delete_hash = NULL;
-  const gchar* proxy_uri;
+  const gchar *proxy_uri;
   SoupURI *soup_proxy_uri;
-#if DEBUG > 0
+#ifdef DEBUG
   SoupLogger *log;
 #endif
   guint status;
@@ -69,7 +69,7 @@ imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
   title = g_value_get_string (&g_array_index (param_values, GValue, 1));
 
   session = soup_session_new ();
-#if DEBUG > 0
+#ifdef DEBUG
   log = soup_logger_new (SOUP_LOGGER_LOG_HEADERS, -1);
   soup_session_add_feature (session, (SoupSessionFeature *)log);
 #endif
@@ -101,7 +101,7 @@ imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
   soup_multipart_append_form_string (mp, "title", title);
   msg = soup_form_request_new_from_multipart (upload_url, mp);
 
-  // for v3 API - key registered *only* for xfce4-screenshooter!
+  /* for v3 API - key registered *only* for xfce4-screenshooter! */
   soup_message_headers_append (msg->request_headers, "Authorization", "Client-ID 66ab680b597e293");
   exo_job_info_message (EXO_JOB (job), _("Upload the screenshot..."));
   status = soup_session_send_message (session, msg);
