@@ -17,12 +17,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "screenshooter-utils.h"
+
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
-
-#include "screenshooter-utils.h"
 #include <libxfce4ui/libxfce4ui.h>
 
 
@@ -148,6 +148,7 @@ screenshooter_read_rc_file (const gchar *file, ScreenshotData *sd)
   gchar *app = g_strdup ("none");
   gchar *last_user = g_strdup ("");
   gchar *last_extension = g_strdup ("png");
+  gchar *last_custom_action_command = g_strdup ("none");
   gboolean enable_imgur_upload = TRUE;
 
   if (G_LIKELY (file != NULL))
@@ -172,6 +173,9 @@ screenshooter_read_rc_file (const gchar *file, ScreenshotData *sd)
           g_free (app);
           app = g_strdup (xfce_rc_read_entry (rc, "app", "none"));
 
+          g_free (last_custom_action_command);
+          last_custom_action_command = g_strdup (xfce_rc_read_entry (rc, "custom_action_command", "none"));
+
           g_free (last_user);
           last_user = g_strdup (xfce_rc_read_entry (rc, "last_user", ""));
 
@@ -209,6 +213,7 @@ screenshooter_read_rc_file (const gchar *file, ScreenshotData *sd)
   sd->last_extension = last_extension;
   sd->enable_imgur_upload = enable_imgur_upload;
   sd->show_in_folder = show_in_folder;
+  sd->custom_action_command = last_custom_action_command;
 }
 
 
@@ -233,6 +238,7 @@ screenshooter_write_rc_file (const gchar *file, ScreenshotData *sd)
   TRACE ("Write the entries.");
 
   xfce_rc_write_entry (rc, "app", sd->app);
+  xfce_rc_write_entry (rc, "custom_action_command", sd->custom_action_command);
   xfce_rc_write_entry (rc, "last_user", sd->last_user);
   xfce_rc_write_entry (rc, "last_extension", sd->last_extension);
   xfce_rc_write_entry (rc, "screenshot_dir", sd->screenshot_dir);
@@ -690,3 +696,40 @@ screenshooter_is_format_supported (const gchar *format)
 
   return result;
 }
+
+
+
+/* Check whether specified path is a writable directory
+ * @path: URI to the directory
+ */
+gboolean
+screenshooter_is_directory_writable (const gchar *path)
+{
+  GFile *dir;
+  GFileInfo *info;
+  GError *error = NULL;
+  gboolean result;
+
+  dir = g_file_new_for_uri (path);
+  info = g_file_query_info (dir, G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE ","
+                               G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE ","
+                               G_FILE_ATTRIBUTE_STANDARD_TYPE,
+                               G_FILE_QUERY_INFO_NONE, NULL, &error);
+
+  result = (g_file_query_exists (dir, NULL) &&
+            g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY &&
+            g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE) &&
+            g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_EXECUTE));
+
+  if (G_UNLIKELY (info == NULL))
+    {
+      g_warning ("Failed to query file info: %s", path);
+      g_error_free (error);
+      return FALSE;
+    }
+
+  g_object_unref (dir);
+  g_object_unref (info);
+
+  return result;
+}
